@@ -1,5 +1,5 @@
 use super::{input::ParserInput, PResult, Parser};
-use crate::parser::Ctx;
+use crate::{parser::Ctx, Parse};
 use swc_common::Span;
 use swc_css_ast::*;
 
@@ -42,7 +42,7 @@ where
     pub(crate) fn parse_properties(&mut self) -> PResult<Vec<Property>> {
         let mut props = vec![];
 
-        while is_one_of!(self, Ident, "--") {
+        while is!(self, Ident) {
             let p = self.parse_property()?;
             props.push(p);
 
@@ -107,3 +107,21 @@ where
         }
     }
 }
+
+impl<I> Parse<Property> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<Property> {
+        self.parse_property()
+    }
+}
+
+impl<I> Parse<Vec<Property>> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<Vec<Property>> {
+        self.parse_properties()
+    }
+}
